@@ -1,4 +1,4 @@
-/* $Id: libgnomevfsmm.h,v 1.7 2003/07/21 20:54:04 mxpxpod Exp $ */
+/* $Id: libgnomevfsmm.h,v 1.8 2003/12/22 17:11:59 murrayc Exp $ */
 /* libgnomevfsmm - a C++ wrapper for libgda
  *
  * Copyright 1999-2003 Free Software Foundation
@@ -26,7 +26,7 @@ extern const int libgnomevfsmm_major_version;
 extern const int libgnomevfsmm_minor_version;
 extern const int libgnomevfsmm_micro_version;
 
-#include <gtkmm.h> //TODO: This should be glibmm.h, when it is distributed separately from gtkmm.
+#include <glibmm.h>
 
 #include <libgnomevfsmm/init.h>
 #include <libgnomevfsmm/application-registry.h>
